@@ -17,7 +17,7 @@
 # under the License.
 from __future__ import annotations
 
-from unittest.mock import MagicMock
+from unittest.mock import MagicMock, patch
 
 import pytest
 
@@ -25,19 +25,20 @@ import airflow.models.xcom
 from airflow.providers.common.io.xcom.backend import XComObjectStorageBackend
 from airflow.providers.standard.operators.empty import EmptyOperator
 from airflow.utils import timezone
-from airflow.utils.xcom import XCOM_RETURN_KEY
 
 from tests_common.test_utils import db
 from tests_common.test_utils.config import conf_vars
-from tests_common.test_utils.version_compat import AIRFLOW_V_3_0_PLUS
+from tests_common.test_utils.version_compat import AIRFLOW_V_3_0_PLUS, XCOM_RETURN_KEY
 
 pytestmark = [pytest.mark.db_test]
 
 if AIRFLOW_V_3_0_PLUS:
     from airflow.models.xcom import XComModel
+    from airflow.sdk import ObjectStoragePath
     from airflow.sdk.execution_time.comms import XComResult
     from airflow.sdk.execution_time.xcom import resolve_xcom_backend
 else:
+    from airflow.io.path import ObjectStoragePath  # type: ignore[no-redef]
     from airflow.models.xcom import BaseXCom, resolve_xcom_backend  # type: ignore[no-redef]
 
 
@@ -373,6 +374,11 @@ class TestXComObjectStorageBackend:
     @pytest.mark.parametrize(
         "value, expected_value",
         [
+            pytest.param(
+                "file://airflow/xcoms/non_existing_file.json",
+                "file://airflow/xcoms/non_existing_file.json",
+                id="str",
+            ),
             pytest.param(1, 1, id="int"),
             pytest.param(1.0, 1.0, id="float"),
             pytest.param("string", "string", id="str"),
@@ -385,11 +391,23 @@ class TestXComObjectStorageBackend:
         ],
     )
     def test_serialization_deserialization_basic(self, value, expected_value):
-        XCom = resolve_xcom_backend()
-        airflow.models.xcom.XCom = XCom
+        def conditional_side_effect(data) -> ObjectStoragePath:
+            if isinstance(data, str) and data.startswith("file://"):
+                return ObjectStoragePath(data)
+            return original_get_full_path(data)
 
-        serialized_data = XCom.serialize_value(value)
-        mock_xcom_ser = MagicMock(value=serialized_data)
-        deserialized_data = XCom.deserialize_value(mock_xcom_ser)
+        original_get_full_path = XComObjectStorageBackend._get_full_path
 
-        assert deserialized_data == expected_value
+        with patch.object(
+            XComObjectStorageBackend,
+            "_get_full_path",
+            side_effect=conditional_side_effect,
+        ):
+            XCom = resolve_xcom_backend()
+            airflow.models.xcom.XCom = XCom
+
+            serialized_data = XCom.serialize_value(value)
+            mock_xcom_ser = MagicMock(value=serialized_data)
+            deserialized_data = XCom.deserialize_value(mock_xcom_ser)
+
+            assert deserialized_data == expected_value
